OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Impossibile scrivere nella cartella \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\"",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
    "See %s" : "Vedi %s",
    "This can usually be fixed by giving the webserver write access to the config directory." : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\".",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
    "Sample configuration detected" : "Configurazione di esempio rilevata",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
    "Other activities" : "Altre attività",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education Edition" : "Edizione didattica",
    "Enterprise bundle" : "Pacchetto Enterprise",
    "Groupware bundle" : "Pacchetto Groupware",
    "Hub bundle" : "Pacchetto Hub",
    "Social sharing bundle" : "Pacchetto Social sharing",
    "PHP %s or higher is required." : "Richiesto PHP %s o superiore",
    "PHP with a version lower than %s is required." : "Richiesta una versione di PHP minore di %s.",
    "%sbit or higher PHP required." : "Richiesto PHP %sbit o superiore.",
    "The following architectures are supported: %s" : "Sono supportate le seguenti architetture: %s",
    "The following databases are supported: %s" : "I seguenti database sono supportati: %s",
    "The command line tool %s could not be found" : "Lo strumento da riga di comando %s non è stato trovato",
    "The library %s is not available." : "La libreria %s non è disponibile.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s maggiore di %2$s - versione disponibile %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Richiesta una versione della libreria %1$s minore di %2$s - versione disponibile %3$s.",
    "The following platforms are supported: %s" : "Le seguenti piattaforme sono supportate: %s",
    "Server version %s or higher is required." : "È richiesta la versione %s o successiva.",
    "Server version %s or lower is required." : "È richiesta la versione %s o precedente.",
    "Logged in user must be an admin or sub admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore o sub-amministratore",
    "Logged in user must be an admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore ",
    "Wiping of device %s has started" : "La cancellazione del dispositivo %s è iniziata",
    "Wiping of device »%s« has started" : "La cancellazione del dispositivo «%s» è iniziata",
    "»%s« started remote wipe" : "«%s» ha iniziato la cancellazione remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Il dispositivo o l'applicazione «%s» ha iniziato il processo di cancellazione remota. Riceverai un'altra email al termine del processo ",
    "Wiping of device %s has finished" : "La cancellazione del dispositivo %s è terminata",
    "Wiping of device »%s« has finished" : "La cancellazione del dispositivo «%s» è terminata",
    "»%s« finished remote wipe" : "«%s» ha terminato la cancellazione remota",
    "Device or application »%s« has finished the remote wipe process." : "Il dispositivo o l'applicazione «%s» ha terminato il processo di cancellazione remota.",
    "Remote wipe started" : "Cancellazione remota avviata",
    "A remote wipe was started on device %s" : "Una cancellazione remota è stata avviata sul dispositivo %s",
    "Remote wipe finished" : "Cancellazione remota terminata",
    "The remote wipe on %s has finished" : "La cancellazione remota su %s è terminata",
    "Authentication" : "Autenticazione",
    "Unknown filetype" : "Tipo di file sconosciuto",
    "Invalid image" : "Immagine non valida",
    "Avatar image is not square" : "L'immagine personale non è quadrata",
    "today" : "oggi",
    "tomorrow" : "domani",
    "yesterday" : "ieri",
    "_in %n day_::_in %n days_" : ["tra %n giorno","tra %n giorni"],
    "_%n day ago_::_%n days ago_" : ["%d giorno fa","%n giorni fa"],
    "next month" : "il prossimo mese",
    "last month" : "mese scorso",
    "_in %n month_::_in %n months_" : ["tra %n mese","tra %n mesi"],
    "_%n month ago_::_%n months ago_" : ["%n mese fa","%n mesi fa"],
    "next year" : "il prossimo anno",
    "last year" : "anno scorso",
    "_in %n year_::_in %n years_" : ["tra %n anno","tra %n anni"],
    "_%n year ago_::_%n years ago_" : ["%n anno fa","%n anni fa"],
    "_in %n hour_::_in %n hours_" : ["tra %n ora","tra %n ore"],
    "_%n hour ago_::_%n hours ago_" : ["%n ora fa","%n ore fa"],
    "_in %n minute_::_in %n minutes_" : ["tra %n minuto","tra %n minuti"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto fa","%n minuti fa"],
    "in a few seconds" : "tra pochi secondi",
    "seconds ago" : "secondi fa",
    "Empty file" : "File vuoto",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con ID: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
    "File name is a reserved word" : "Il nome del file è una parola riservata",
    "File name contains at least one invalid character" : "Il nome del file contiene almeno un carattere non valido",
    "File name is too long" : "Il nome del file è troppo lungo",
    "Dot files are not allowed" : "I file con un punto iniziale non sono consentiti",
    "Empty filename is not allowed" : "Un nome di file vuoto non è consentito",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'applicazione \"%s\" non può essere installata poiché il file appinfo non può essere letto.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'applicazione \"%s\" non può essere installata perché non è compatibile con questa versione del server.",
    "__language_name__" : "Italiano",
    "This is an automatically sent email, please do not reply." : "Questo è un messaggio di posta inviato automaticamente, non rispondere.",
    "Help" : "Aiuto",
    "Apps" : "Applicazioni",
    "Settings" : "Impostazioni",
    "Log out" : "Esci",
    "Users" : "Utenti",
    "Unknown user" : "Utente sconosciuto",
    "Additional settings" : "Impostazioni aggiuntive",
    "%s enter the database username and name." : "%s digita il nome utente e il nome del database.",
    "%s enter the database username." : "%s digita il nome utente del database.",
    "%s enter the database name." : "%s digita il nome del database.",
    "%s you may not use dots in the database name" : "%s non dovresti utilizzare punti nel nome del database",
    "MySQL username and/or password not valid" : "Nome utente e/o password di MySQL non validi",
    "You need to enter details of an existing account." : "Devi inserire i dettagli di un account esistente.",
    "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
    "Oracle username and/or password not valid" : "Nome utente e/o password di Oracle non validi",
    "PostgreSQL username and/or password not valid" : "Nome utente e/o password di PostgreSQL non validi",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non è supportato e %s non funzionerà correttamente su questa piattaforma. Usalo a tuo rischio!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
    "Set an admin username." : "Imposta un nome utente di amministrazione.",
    "Set an admin password." : "Imposta una password di amministrazione.",
    "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
    "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
    "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha condiviso «%2$s» con te e vuole aggiungere",
    "»%s« added a note to a file shared with you" : "«%s» ha aggiunto una nota a un file condiviso con te",
    "Open »%s«" : "Apri «%s»",
    "%1$s via %2$s" : "%1$s tramite %2$s",
    "You are not allowed to share %s" : "Non ti è consentito condividere %s",
    "Can’t increase permissions of %s" : "Impossibile aumentare i permessi di %s",
    "Files can’t be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
    "Files can’t be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
    "Expiration date is in the past" : "La data di scadenza è nel passato",
    "Can’t set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
    "%1$s shared »%2$s« with you" : "%1$s ha condiviso «%2$s» con te",
    "%1$s shared »%2$s« with you." : "%1$s ha condiviso «%2$s» con te.",
    "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
    "The requested share does not exist anymore" : "La condivisione richiesta non esiste più",
    "Could not find category \"%s\"" : "Impossibile trovare la categoria \"%s\"",
    "Sunday" : "Domenica",
    "Monday" : "Lunedì",
    "Tuesday" : "Martedì",
    "Wednesday" : "Mercoledì",
    "Thursday" : "Giovedì",
    "Friday" : "Venerdì",
    "Saturday" : "Sabato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Gio.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Gi",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Gennaio",
    "February" : "Febbraio",
    "March" : "Marzo",
    "April" : "Aprile",
    "May" : "Maggio",
    "June" : "Giugno",
    "July" : "Luglio",
    "August" : "Agosto",
    "September" : "Settembre",
    "October" : "Ottobre",
    "November" : "Novembre",
    "December" : "Dicembre",
    "Jan." : "Gen.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mag.",
    "Jun." : "Giu.",
    "Jul." : "Lug.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Ott.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "The user limit has been reached and the user was not created." : "È stato raggiunto il limite di utenti e l'utente non è stato creato.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
    "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
    "Username must not consist of dots only" : "Il nome utente non può consistere di soli punti",
    "Username is invalid because files already exist for this user" : "Il nome utente non è valido poiché esiste già per questo utente",
    "A valid password must be provided" : "Deve essere fornita una password valida",
    "The username is already being used" : "Il nome utente è già utilizzato",
    "Could not create user" : "Impossibile creare l'utente",
    "User disabled" : "Utente disabilitato",
    "Login canceled by app" : "Accesso annullato dall'applicazione",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'applicazione \"%1$s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %2$s",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
    "Can't read file" : "Impossibile leggere il file",
    "Application is not enabled" : "L'applicazione  non è abilitata",
    "Authentication error" : "Errore di autenticazione",
    "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
    "Cannot write into \"config\" directory" : "Impossibile scrivere nella cartella \"config\"",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella di configurazione. Vedi %s",
    "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Questo può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"apps\" o disabilitando il negozio di applicazioni nel file di configurazione.",
    "Cannot create \"data\" directory" : "Impossibile creare la cartella \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "I permessi possono essere normalmente corretti fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
    "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
    "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
    "PHP module %s not installed." : "Il modulo PHP %s non è installato.",
    "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "L'impostazione \"%s\" di PHP non è configurata a \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Per eseguire nuovamente Nextcloud, modificare questa impostazione nel file php.ini",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "È richiesta almeno la versione 2.7.0 di libxml2. Quella attualmente installata è la %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Per risolvere questo problema, aggiorna la tua versione di libxml2 e riavvia il server web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Sono stati installati moduli PHP, ma sono elencati ancora come mancanti?",
    "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
    "PostgreSQL >= 9 required" : "Richiesto PostgreSQL >= 9",
    "Please upgrade your database version" : "Aggiorna la versione del tuo database",
    "Your data directory is readable by other users" : "La cartella dei dati è leggibile dagli altri utenti",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
    "Your data directory must be an absolute path" : "La cartella dei dati deve essere un percorso assoluto",
    "Check the value of \"datadirectory\" in your configuration" : "Controlla il valore di \"datadirectory\" nella tua configurazione",
    "Your data directory is invalid" : "La cartella dei dati non è valida",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assicurati che ci sia un file \".ocdata\" nella radice della cartella data.",
    "Action \"%s\" not supported or implemented." : "Azione \"%s\" non supportata o implementata.",
    "Authentication failed, wrong token or provider ID given" : "Autenticazione non riuscita, token o ID fornitore errato ",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametri mancanti per completare la richiesta. Parametri mancanti: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" già utilizzato dal fornitore della federazione cloud \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Il fornitore della federazione cloud con ID: \"%s\" non esiste.",
    "Could not obtain lock type %d on \"%s\"." : "Impossibile ottenere il blocco di tipo %d su \"%s\".",
    "Storage unauthorized. %s" : "Archiviazione non autorizzata. %s",
    "Storage incomplete configuration. %s" : "Configurazione dell'archiviazione incompleta.%s",
    "Storage connection error. %s" : "Errore di connessione all'archiviazione. %s",
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage connection timeout. %s" : "Timeout di connessione all'archiviazione. %s",
    "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
    "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
    "Overview" : "Riepilogo",
    "Basic settings" : "Impostazioni di base",
    "Sharing" : "Condivisione",
    "Security" : "Sicurezza",
    "Groupware" : "Groupware",
    "Personal info" : "Informazioni personali",
    "Mobile & desktop" : "Mobile e desktop",
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella delle applicazioni o disabilitando il negozio di applicazioni nel file di configurazione. Vedi %s"
},
"nplurals=2; plural=(n != 1);");
